from cjkcms.tests.test_templatetags import TemplateTagTests
from cjkcms.tests.test_settings import SettingsTests
from cjkcms.tests.test_gravatar import (
    GravatarTests,
    GravatarWithDefaultGravatarUrlTests,
)
from cjkcms.tests.test_articlepages import ArticlePageTests
from cjkcms.tests.test_webpage import WebPageTests
from cjkcms.tests.test_urls import TestFavicon, TestSiteURLs
